=========
Changelog
=========

------------------
0.2.1 (2019-12-29)
------------------

* Package sub-modules
* Fix Travis auto-deployment to PyPI
* Upgrade numpy dependency

------------------
0.2.0 (2019-12-27)
------------------

* Regression tests - serial and distributed (condor)
* Sympy to manage simulated model
* Pairwise interaction analysis
* Corrected adjusted p-values for non-rejected nodes
* Various minor fixes and documentation updates

------------------
0.1.1 (2018-09-14)
------------------

* First release on PyPI
